.. -*-restructuredtext-*-

roswire
=======

.. image:: https://travis-ci.org/ChrisTimperley/roswire.svg?branch=master
    :target: https://travis-ci.org/ChrisTimperley/roswire

Feature Roadmap
----------------

* Supports ROS 1 and 2.
* Differential coverage collection for C, C++ and Java.
* Highly parallel: interact with multiple systems simultaneously.
* Mutation API: quickly apply random source-code mutations to SUTs.
* Simulation speedup.
* Plugin-based simulator support.
* Modular oracles.
* Trace collection and streaming.


Applications
------------

* Property-based testing
* Blackbox fuzzing
* Model discovery
